@@ -24,17 +24,17 @@
 #include <kmimetype.h>
 #include <qfileinfo.h>
 #include <qdir.h>
-#include <archivereader.h>
+#include <strigi/archivereader.h>
 #include <vector>
 
 #include "jstream.h"
-#include <fileinputstream.h>
+#include <strigi/fileinputstream.h>
 
 // http://www.heise.de/ct/english/01/05/242/
 
 using namespace KIO;
 using namespace std;
-using namespace jstreams;
+using namespace Strigi;
 
 class QFileStreamOpener : public StreamOpener {
 public:
@@ -45,7 +45,7 @@ public:
 StreamBase<char>*
 QFileStreamOpener::openStream(const string& url) {
     StreamBase<char>* stream = new FileInputStream(QString(url.c_str()));
-    if (stream->getStatus() != Ok) {
+    if (stream->status() != Ok) {
         delete stream;
         stream = 0;
     }
@@ -91,7 +91,7 @@ kio_jstreamProtocol::get(const KURL& url ) {
     string path = (const char*)url.path().utf8();
     if (path.size() && path[path.size()-1] == '/') path.resize(path.size()-1);
 
-    jstreams::StreamBase<char>* in = reader->openStream(path);
+    Strigi::StreamBase<char>* in = reader->openStream(path);
     if (in == 0) {
         error( KIO::ERR_CANNOT_OPEN_FOR_READING, path );
         return;
@@ -159,7 +159,7 @@ kio_jstreamProtocol::statQFileInfo(const QFileInfo& f) const {
         if (path.size() && path[path.size() - 1] == '/') {
             path.resize(path.size() - 1);
         }
-        DirLister dl = reader->getDirEntries(path);
+        DirLister dl = reader->dirEntries(path);
         EntryInfo e;
         if (dl.nextEntry(e)) {
             entry = makeDirEntry(f.fileName(), f.size());
@@ -243,7 +243,7 @@ kio_jstreamProtocol::listDir(const KURL& url) {
     if (path.size() && path[path.size() - 1] == '/') {
         path.resize(path.size() - 1);
     }
-    DirLister dl = reader->getDirEntries(path);
+    DirLister dl = reader->dirEntries(path);
     EntryInfo e;
     while (dl.nextEntry(e)) {
         entry = entryInfoToUDSEntry(e);
